@@ -1,7 +1,7 @@
 # Net::Cmd.pm
 #
 # Copyright (C) 1995-2006 Graham Barr.  All rights reserved.
-# Copyright (C) 2013-2016, 2020 Steve Hay.  All rights reserved.
+# Copyright (C) 2013-2016, 2020, 2022 Steve Hay.  All rights reserved.
 # This module is free software; you can redistribute it and/or modify it under
 # the same terms as Perl itself, i.e. under the terms of either the GNU General
 # Public License or the Artistic License, as specified in the F<LICENCE> file.
@@ -19,14 +19,14 @@ use Symbol 'gensym';
 use Errno 'EINTR';
 
 BEGIN {
-  if ($^O eq 'os390') {
+  if (ord "A" == 193) {
     require Convert::EBCDIC;
 
     #    Convert::EBCDIC->import;
   }
 }
 
-our $VERSION = "3.12";
+our $VERSION = "3.15";
 our @ISA     = qw(Exporter);
 our @EXPORT  = qw(CMD_INFO CMD_OK CMD_MORE CMD_REJECT CMD_ERROR CMD_PENDING);
 
@@ -41,7 +41,7 @@ use constant DEF_REPLY_CODE => 421;
 
 my %debug = ();
 
-my $tr = $^O eq 'os390' ? Convert::EBCDIC->new() : undef;
+my $tr = ord "A" == 193 ? Convert::EBCDIC->new() : undef;
 
 sub toebcdic {
   my $cmd = shift;
@@ -335,19 +335,15 @@ sub getline {
   my $rin = "";
   vec($rin, $fd, 1) = 1;
 
-  my $timeout = $cmd->timeout || undef;
-  my $initial = time;
-  my $pending = $timeout;
-
   my $buf;
 
   until (scalar(@{${*$cmd}{'net_cmd_lines'}})) {
+    my $timeout = $cmd->timeout || undef;
     my $rout;
 
-    my $select_ret = select($rout = $rin, undef, undef, $pending);
-    if (defined $select_ret and $select_ret > 0) {
-      my $r = sysread($cmd, $buf = "", 1024);
-      if (! defined($r) ) {
+    my $select_ret = select($rout = $rin, undef, undef, $timeout);
+    if ($select_ret > 0) {
+      unless (sysread($cmd, $buf = "", 1024)) {
         my $err = $!;
         $cmd->close;
         $cmd->_set_status_closed($err);
@@ -363,20 +359,6 @@ sub getline {
       push(@{${*$cmd}{'net_cmd_lines'}}, map {"$_\n"} @buf);
 
     }
-    elsif (defined $select_ret && $select_ret == -1) {
-      if ( $! == EINTR ) {
-        if ( defined($timeout) ) {
-          redo if ($pending = $timeout - ( time - $initial ) ) > 0;
-          $cmd->_set_status_timeout;
-          return;
-        }
-        redo;
-      }
-      my $err = $!;
-      $cmd->close;
-      $cmd->_set_status_closed($err);
-      return;
-    }
     else {
       $cmd->_set_status_timeout;
       return;
@@ -905,7 +887,7 @@ libnet as of version 1.22_02.
 
 Copyright (C) 1995-2006 Graham Barr.  All rights reserved.
 
-Copyright (C) 2013-2016, 2020 Steve Hay.  All rights reserved.
+Copyright (C) 2013-2016, 2020, 2022 Steve Hay.  All rights reserved.
 
 =head1 LICENCE
 
@@ -915,11 +897,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 3.12
+Version 3.15
 
 =head1 DATE
 
-09 Dec 2020
+20 March 2023
 
 =head1 HISTORY
 
